@@ -179,8 +179,9 @@ def apply_index_offset(
 
     if not expression.type:
         annotate_types(expression)
+
     if t.cast(exp.DataType, expression.type).this in exp.DataType.INTEGER_TYPES:
-        logger.warning("Applying array index offset (%s)", offset)
+        logger.info("Applying array index offset (%s)", offset)
         expression = simplify(expression + offset)
         return [expression]
 
