@@ -16,16 +16,17 @@ def canonicalize(expression: exp.Expression) -> exp.Expression:
     Args:
         expression: The expression to canonicalize.
     """
-    exp.replace_children(expression, canonicalize)
 
-    expression = add_text_to_concat(expression)
-    expression = replace_date_funcs(expression)
-    expression = coerce_type(expression)
-    expression = remove_redundant_casts(expression)
-    expression = ensure_bools(expression, _replace_int_predicate)
-    expression = remove_ascending_order(expression)
+    def _canonicalize(expression: exp.Expression) -> exp.Expression:
+        expression = add_text_to_concat(expression)
+        expression = replace_date_funcs(expression)
+        expression = coerce_type(expression)
+        expression = remove_redundant_casts(expression)
+        expression = ensure_bools(expression, _replace_int_predicate)
+        expression = remove_ascending_order(expression)
+        return expression
 
-    return expression
+    return exp.replace_tree(expression, _canonicalize)
 
 
 def add_text_to_concat(node: exp.Expression) -> exp.Expression:
@@ -35,9 +36,13 @@ def add_text_to_concat(node: exp.Expression) -> exp.Expression:
 
 
 def replace_date_funcs(node: exp.Expression) -> exp.Expression:
-    if isinstance(node, exp.Date) and not node.expressions and not node.args.get("zone"):
+    if (
+        isinstance(node, (exp.Date, exp.TsOrDsToDate))
+        and not node.expressions
+        and not node.args.get("zone")
+    ):
         return exp.cast(node.this, to=exp.DataType.Type.DATE)
-    if isinstance(node, exp.Timestamp) and not node.expression:
+    if isinstance(node, exp.Timestamp) and not node.args.get("zone"):
         if not node.type:
             from sqlglot.optimizer.annotate_types import annotate_types
 
@@ -121,15 +126,11 @@ def _coerce_date(a: exp.Expression, b: exp.Expression) -> None:
             a = _coerce_timeunit_arg(a, b.unit)
         if (
             a.type
-            and a.type.this == exp.DataType.Type.DATE
+            and a.type.this in exp.DataType.TEMPORAL_TYPES
             and b.type
-            and b.type.this
-            not in (
-                exp.DataType.Type.DATE,
-                exp.DataType.Type.INTERVAL,
-            )
+            and b.type.this in exp.DataType.TEXT_TYPES
         ):
-            _replace_cast(b, exp.DataType.Type.DATE)
+            _replace_cast(b, exp.DataType.Type.DATETIME)
 
 
 def _coerce_timeunit_arg(arg: exp.Expression, unit: t.Optional[exp.Expression]) -> exp.Expression:
@@ -169,7 +170,7 @@ def _replace_cast(node: exp.Expression, to: exp.DataType.Type) -> None:
 # with y as (select true as x) select x = 0 FROM y -- illegal presto query
 def _replace_int_predicate(expression: exp.Expression) -> None:
     if isinstance(expression, exp.Coalesce):
-        for _, child in expression.iter_expressions():
+        for child in expression.iter_expressions():
             _replace_int_predicate(child)
     elif expression.type and expression.type.this in exp.DataType.INTEGER_TYPES:
         expression.replace(expression.neq(0))
