@@ -89,7 +89,8 @@ def eliminate_subqueries(expression):
                 new_ctes.append(new_cte)
 
     if new_ctes:
-        expression.set("with", exp.With(expressions=new_ctes, recursive=recursive))
+        query = expression.expression if isinstance(expression, exp.DDL) else expression
+        query.set("with", exp.With(expressions=new_ctes, recursive=recursive))
 
     return expression
 
