@@ -48,6 +48,42 @@ class TestDoris(Validator):
                 "postgres": """SELECT JSON_EXTRACT_PATH(CAST('{"key": 1}' AS JSONB), 'key')""",
             },
         )
+        self.validate_all(
+            "SELECT GROUP_CONCAT('aa', ',')",
+            read={
+                "doris": "SELECT GROUP_CONCAT('aa', ',')",
+                "mysql": "SELECT GROUP_CONCAT('aa' SEPARATOR ',')",
+                "postgres": "SELECT STRING_AGG('aa', ',')",
+            },
+        )
+        self.validate_all(
+            "SELECT LAG(1, 1, NULL) OVER (ORDER BY 1)",
+            read={
+                "doris": "SELECT LAG(1, 1, NULL) OVER (ORDER BY 1)",
+                "postgres": "SELECT LAG(1) OVER (ORDER BY 1)",
+            },
+        )
+        self.validate_all(
+            "SELECT LAG(1, 2, NULL) OVER (ORDER BY 1)",
+            read={
+                "doris": "SELECT LAG(1, 2, NULL) OVER (ORDER BY 1)",
+                "postgres": "SELECT LAG(1, 2) OVER (ORDER BY 1)",
+            },
+        )
+        self.validate_all(
+            "SELECT LEAD(1, 1, NULL) OVER (ORDER BY 1)",
+            read={
+                "doris": "SELECT LEAD(1, 1, NULL) OVER (ORDER BY 1)",
+                "postgres": "SELECT LEAD(1) OVER (ORDER BY 1)",
+            },
+        )
+        self.validate_all(
+            "SELECT LEAD(1, 2, NULL) OVER (ORDER BY 1)",
+            read={
+                "doris": "SELECT LEAD(1, 2, NULL) OVER (ORDER BY 1)",
+                "postgres": "SELECT LEAD(1, 2) OVER (ORDER BY 1)",
+            },
+        )
 
     def test_identity(self):
         self.validate_identity("COALECSE(a, b, c, d)")
